//////////////////////////////////////////////////////////////////////////////
//
// ***************************************************************************
// **                                                                       **
// ** Copyright (c) 1995-2004 Xilinx, Inc.  All rights reserved.            **
// **                                                                       **
// ** You may copy and modify these files for your own internal use solely  **
// ** with Xilinx programmable logic devices and Xilinx EDK system or       **
// ** create IP modules solely for Xilinx programmable logic devices and    **
// ** Xilinx EDK system. No rights are granted to distribute any files      **
// ** unless they are distributed in Xilinx programmable logic devices.     **
// **                                                                       **
// ***************************************************************************
//
//////////////////////////////////////////////////////////////////////////////
// Filename:          C:\projekte\Virtex_II_XC2V250_board\fpga\MyProcessorIPLib\drivers\opb_usb_ft245_v1_00_b\src\opb_usb_ft245.h
// Version:           1.00.b
// Description:       opb_usb_ft245 Driver Header File
// Date:              Wed Mar 16 10:08:06 2005 (by Create and Import Peripheral Wizard)
//////////////////////////////////////////////////////////////////////////////

#ifndef OPB_USB_FT245_H
#define OPB_USB_FT245_H

//--------------------------------------------------------------------------------------------
// Include Files

#include "xbasic_types.h"
#include "xio.h"

//--------------------------------------------------------------------------------------------
// Constant Definitions

// FT245 IP register offsets
#define USB_FT245_STATUS_REG_OFFSET			0			// status register, read only
#define USB_FT245_RX_FIFO_OFFSET			1			// when read receive FIFO
#define USB_FT245_TX_FIFO_OFFSET   			1			// when written transmit FIFO

// status register bit positions
#define USB_FT245_SR_TX_FIFO_FULL			0x01		// transmit FIFO full
#define USB_FT245_SR_RX_FIFO_VALID_DATA		0x02		// data in receive FIFO

//--------------------------------------------------------------------------------------------
// Macros (Inline Functions) Definitions

//********************************************************************************************
// Write a value to a OPB_USB_FT245 register. A 8 bit write is performed.
//
// @param   BaseAddress is the base address of the OPB_USB_FT245 device.
// @param   RegOffset is the register offset from the base to write to.
// @param   Data is the data written to the register.
// @return  None.
// @note    None.
//
// C-style signature:
// void OPB_USB_FT245_mWriteReg(Xuint8 BaseAddress, unsigned RegOffset, Xuint8 Data)
//********************************************************************************************
#define USB_FT245_mWriteReg(BaseAddress, RegOffset, Data) \
 	XIo_Out8((BaseAddress) + (RegOffset), (Xuint8)(Data))

//********************************************************************************************
// Read a value from a OPB_USB_FT245 register. A 8 bit read is performed.
//
// @param   BaseAddress is the base address of the OPB_USB_FT245 device.
// @param   RegOffset is the register offset from the base to write to.
// @return  Data is the data from the register.
// @note    None.
//
// C-style signature:
// Xuint8 USB_FT245_mReadReg(Xuint8 BaseAddress, unsigned RegOffset)
//********************************************************************************************
#define USB_FT245_mReadReg(BaseAddress, RegOffset) \
 	XIo_In8((BaseAddress) + (RegOffset))

//********************************************************************************************
// Get the contents of the status register. Use the FT245_SR_* constants defined above to
// interpret the bit-mask returned.
//
// @param    BaseAddress is the  base address of the device
// @return   A 32-bit value representing the contents of the status register.
// @note     None.
//********************************************************************************************
#define USB_FT245_mGetStatusReg(BaseAddress) \
		XIo_In8((BaseAddress) + USB_FT245_STATUS_REG_OFFSET)

//********************************************************************************************
// Check to see if the receiver has data.
//
// @param    BaseAddress is the  base address of the device
// @return   XTRUE if the receiver is empty, XFALSE if there is data present.
// @note     None.
//********************************************************************************************
#define USB_FT245_mIsReceiverEmpty(BaseAddress) \
  ((USB_FT245_mGetStatusReg((BaseAddress)) & USB_FT245_SR_RX_FIFO_VALID_DATA) == \
    USB_FT245_SR_RX_FIFO_VALID_DATA)

//********************************************************************************************
// Check to see if the transmitter is full.
//
// @param    BaseAddress is the  base address of the device
// @return   XTRUE if the transmitter is full, XFALSE otherwise.
// @note     None.
//********************************************************************************************
#define USB_FT245_mIsTransmitterFull(BaseAddress) \
    ((USB_FT245_mGetStatusReg((BaseAddress)) & USB_FT245_SR_TX_FIFO_FULL) == \
      USB_FT245_SR_TX_FIFO_FULL)

//--------------------------------------------------------------------------------------------
// Function Prototypes
void USB_FT245_SendByte(Xuint32 BaseAddress, Xuint8 Data);
Xuint8 USB_FT245_RecvByte(Xuint32 BaseAddress);
void USB_FT245_FlushRXFifo(Xuint32 BaseAddress);

#endif // OPB_USB_FT245_H
